@@ -1,22 +1,14 @@
-from zope.interface import Interface
-from zope.interface import directlyProvides
-
-# BBB Zope 2.12
-try:
-    from zope.browsermenu.interfaces import IBrowserMenu
-    from zope.browsermenu.interfaces import IBrowserSubMenuItem
-    from zope.browsermenu.interfaces import IMenuItemType
-except ImportError:
-    from zope.app.publisher.interfaces.browser import IBrowserMenu
-    from zope.app.publisher.interfaces.browser import IBrowserSubMenuItem
-    from zope.app.publisher.interfaces.browser import IMenuItemType
-
+# -*- coding: utf-8 -*-
+from zope.browsermenu.interfaces import IBrowserMenu
+from zope.browsermenu.interfaces import IBrowserSubMenuItem
+from zope.browsermenu.interfaces import IMenuItemType
 from zope.contentprovider.interfaces import IContentProvider
+from zope.interface import Interface
+from zope.interface import provider
 
 
 class IContentMenuView(IContentProvider):
-    """The view that powers the content menu (the green bar at the top of
-    the editable border).
+    """The view that powers the content menu in the toolbar.
 
     This will construct a menu by finding an adapter to IContentMenu.
     """
@@ -37,10 +29,11 @@ class IContentMenuView(IContentProvider):
 # interface (this is signalled by marking the interface itself with the
 # IInterface IMenuItemType)
 
+
+@provider(IMenuItemType)
 class IContentMenuItem(Interface):
     """Special menu item type for Plone's content menu."""
 
-directlyProvides(IContentMenuItem, IMenuItemType)
 
 # The sub-menus - because they require additional logic, each of these will be
 # implemented with a separate class. We provide markers here to distinguish
@@ -61,16 +54,19 @@ directlyProvides(IContentMenuItem, IMenuItemType)
 #   separator    :   True if the item should be preceded by a separator
 #   hideChildren :   True if the item's children should not be rendered
 
+
 class IActionsSubMenuItem(IBrowserSubMenuItem):
     """The menu item linking to the actions menu.
     """
 
+
 class IActionsMenu(IBrowserMenu):
     """The actions menu.
 
     This gets its menu items from portal_actions.
     """
 
+
 class IDisplaySubMenuItem(IBrowserSubMenuItem):
     """The menu item linking to the display menu.
     """
@@ -78,16 +74,19 @@ class IDisplaySubMenuItem(IBrowserSubMenuItem):
     def disabled(self):
         """Find out if the menu is visible but disabled."""
 
+
 class IDisplayMenu(IBrowserMenu):
     """The display menu.
 
     This gets its menu items from an IBrowserDefault (see CMFDynamicViewFTI).
     """
 
+
 class IFactoriesSubMenuItem(IBrowserSubMenuItem):
     """The menu item linking to the factories menu.
     """
 
+
 class IFactoriesMenu(IBrowserMenu):
     """The factories menu.
 
@@ -95,10 +94,12 @@ class IFactoriesMenu(IBrowserMenu):
     the context.
     """
 
+
 class IWorkflowSubMenuItem(IBrowserSubMenuItem):
     """The menu item linking to the workflow menu.
     """
 
+
 class IWorkflowMenu(IBrowserMenu):
     """The workflow menu.
 
@@ -106,6 +107,19 @@ class IWorkflowMenu(IBrowserMenu):
     portal_workflow.
     """
 
+
+class IPortletManagerSubMenuItem(IBrowserSubMenuItem):
+    """The menu item linking to the portlet manager menu.
+    """
+
+
+class IPortletManagerMenu(IBrowserMenu):
+    """The portlet manager menu.
+
+    This gets its menu items from the list of possible portlet managers.
+    """
+
+
 class IDisplayViewsMenu(IBrowserMenu):
     """A menu listing Zope3 views registered as content views
 
